@@ -6,7 +6,7 @@ require 'metamodels/uml13_metamodel'
 require 'ea_support/ea_support'
 require 'rgen/serializer/xmi11_serializer'
 
-class EASerializerTest < MiniTest::Test
+class EASerializerTest < Minitest::Test
 
 	MODEL_DIR = File.join(File.dirname(__FILE__),"testmodel")
 	TEST_DIR = File.join(File.dirname(__FILE__),"ea_serializer_test")
